==> cdi-tck-impl-1.2.0.CR1-sources.jar: org/jboss/cdi/tck/tests/event/observer/wildcardAndTypeVariable/ObserverMethodWithParametertizedTypeTest.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2010, Red Hat, Inc., and individual contributors
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.jboss.cdi.tck.tests.event.observer.wildcardAndTypeVariable;

import static org.jboss.cdi.tck.cdi.Sections.OBSERVER_METHOD_EVENT_PARAMETER;
import static org.testng.Assert.assertTrue;

import java.util.List;

import org.jboss.arquillian.container.test.api.Deployment;
import org.jboss.cdi.tck.AbstractTest;
import org.jboss.cdi.tck.shrinkwrap.WebArchiveBuilder;
import org.jboss.shrinkwrap.api.spec.WebArchive;
import org.jboss.test.audit.annotations.SpecAssertion;
import org.jboss.test.audit.annotations.SpecVersion;
import org.testng.annotations.Test;

/**
 * Tests an observer method defined to observe an event type which is generic and a type variable
 *
 * @author David Allen
 * @author Martin Kouba
 */
@SpecVersion(spec = "cdi", version = "1.1 Final Release")
public class ObserverMethodWithParametertizedTypeTest extends AbstractTest {

    @Deployment
    public static WebArchive createTestArchive() {
        return new WebArchiveBuilder().withTestClassPackage(ObserverMethodWithParametertizedTypeTest.class).build();
    }

    @Test
    @SpecAssertion(section = OBSERVER_METHOD_EVENT_PARAMETER, id = "ca")
    public void testObserverMethodCanObserveTypeVariable() {
        BostonTerrier.reset();
        Behavior event = new Behavior() {
        };
        getCurrentManager().fireEvent(event);
        assertTrue(BostonTerrier.observedTypeVariable);
    }

    @Test
    @SpecAssertion(section = OBSERVER_METHOD_EVENT_PARAMETER, id = "cb")
    public void testObserverMethodCanObserveWildcardType() {
        BostonTerrier.reset();
        List<Object> event = new ObjectList();
        getCurrentManager().fireEvent(event);
        assertTrue(BostonTerrier.observedWildcard);
    }

    @Test
    @SpecAssertion(section = OBSERVER_METHOD_EVENT_PARAMETER, id = "da")
    public void testObserverMethodCanObserveArrayTypeVariable() {
        BostonTerrier.reset();
        Behavior[] event = new Behavior[] {};
        getCurrentManager().fireEvent(event);
        assertTrue(BostonTerrier.observedArrayTypeVariable);
    }

    @Test
    @SpecAssertion(section = OBSERVER_METHOD_EVENT_PARAMETER, id = "db")
    public void testObserverMethodCanObserveArrayWildcard() {
        BostonTerrier.reset();
        List<?>[] event = new ObjectList[0];
        getCurrentManager().fireEvent(event);
        assertTrue(BostonTerrier.observedArrayWildCard);
    }

}

==> cdi-tck-impl-2.0.0.CR1-sources.jar: org/jboss/cdi/tck/tests/event/observer/wildcardAndTypeVariable/ObserverMethodWithParametertizedTypeTest.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2010, Red Hat, Inc., and individual contributors
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.jboss.cdi.tck.tests.event.observer.wildcardAndTypeVariable;

import static org.jboss.cdi.tck.cdi.Sections.OBSERVER_METHOD_EVENT_PARAMETER;
import static org.testng.Assert.assertTrue;

import java.util.List;

import org.jboss.arquillian.container.test.api.Deployment;
import org.jboss.cdi.tck.AbstractTest;
import org.jboss.cdi.tck.shrinkwrap.WebArchiveBuilder;
import org.jboss.shrinkwrap.api.spec.WebArchive;
import org.jboss.test.audit.annotations.SpecAssertion;
import org.jboss.test.audit.annotations.SpecVersion;
import org.testng.annotations.Test;

/**
 * Tests an observer method defined to observe an event type which is generic and a type variable
 *
 * @author David Allen
 * @author Martin Kouba
 */
@SpecVersion(spec = "cdi", version = "2.0-PFD")
public class ObserverMethodWithParametertizedTypeTest extends AbstractTest {

    @Deployment
    public static WebArchive createTestArchive() {
        return new WebArchiveBuilder().withTestClassPackage(ObserverMethodWithParametertizedTypeTest.class).build();
    }

    @Test
    @SpecAssertion(section = OBSERVER_METHOD_EVENT_PARAMETER, id = "ca")
    public void testObserverMethodCanObserveTypeVariable() {
        BostonTerrier.reset();
        Behavior event = new Behavior() {
        };
        getCurrentManager().fireEvent(event);
        assertTrue(BostonTerrier.observedTypeVariable);
    }

    @Test
    @SpecAssertion(section = OBSERVER_METHOD_EVENT_PARAMETER, id = "cb")
    public void testObserverMethodCanObserveWildcardType() {
        BostonTerrier.reset();
        List<Object> event = new ObjectList();
        getCurrentManager().fireEvent(event);
        assertTrue(BostonTerrier.observedWildcard);
    }

    @Test
    @SpecAssertion(section = OBSERVER_METHOD_EVENT_PARAMETER, id = "da")
    public void testObserverMethodCanObserveArrayTypeVariable() {
        BostonTerrier.reset();
        Behavior[] event = new Behavior[] {};
        getCurrentManager().fireEvent(event);
        assertTrue(BostonTerrier.observedArrayTypeVariable);
    }

    @Test
    @SpecAssertion(section = OBSERVER_METHOD_EVENT_PARAMETER, id = "db")
    public void testObserverMethodCanObserveArrayWildcard() {
        BostonTerrier.reset();
        List<?>[] event = new ObjectList[0];
        getCurrentManager().fireEvent(event);
        assertTrue(BostonTerrier.observedArrayWildCard);
    }

}
